@@ -1,5 +1,5 @@
 import logging
-from typing import Any, Callable, Sequence, Tuple
+from typing import Any, Callable, Dict, Optional, Sequence, Tuple, TypeVar, TypedDict
 
 from django.db.models import Q, QuerySet
 
@@ -9,6 +9,7 @@ from .registry import CodeSeekerRegistry
 __all__ = (
     'CodeSeek',
     'CodeSeekSeq',
+    'CodesFilter',
 
     'EMPTY_Q',
     'cmp_AND',
@@ -21,9 +22,18 @@ __all__ = (
 
 logger = logging.getLogger(__name__)
 
+QT = TypeVar('QT', bound='CodeSeekerQuerySet')
 CodeSeek = Tuple[str, Any]
 CodeSeekSeq = Sequence[CodeSeek]
 
+
+class CodesFilter(TypedDict):
+    codes: CodeSeekSeq
+    registry: CodeSeekerRegistry
+    cmp: Optional[Callable]
+    warning_context: Optional[str]
+
+
 EMPTY_Q = Q()
 
 
@@ -39,11 +49,11 @@ def seek_codes_Q(
     registry: CodeSeekerRegistry,
     codes: CodeSeekSeq,
     cmp: Callable = cmp_AND,
-    warning_context: str = None
+    warning_context: Optional[str] = None
 ) -> Q:
     q = EMPTY_Q
 
-    for code in codes:
+    for code, value in codes:
         if code not in registry:
             logger.warning(
                 f'[CODE-SEEKING-FILTER] No such code "{code}"'
@@ -57,7 +67,7 @@ def seek_codes_Q(
             )
             continue
 
-        q = cmp(q, codes)
+        q = cmp(q, registry[code].Q(value))
 
     return q
 
@@ -75,3 +85,15 @@ class CodeSeekerQuerySet(QuerySet):
         )
 
         return self.filter(q) if q is not EMPTY_Q else self
+
+    def general_filter(
+        self: QT,
+        codes_filter: Optional[CodesFilter] = None,
+        **kw
+    ) -> QT:
+        q = super().general_filter(**kw)
+
+        if codes_filter is not None and codes_filter.get('codes') is not None:
+            q = q.seek_codes(**codes_filter)
+
+        return q
\ No newline at end of file
