@@ -29,6 +29,12 @@ class CodeSeeker:
             f'{field_name or self.field_name}__{self.name}': value
         })
 
+    def eq(self, a: Any, b: Any) -> bool:
+        return a == b
+
+    def ge(self, a: Any, b: Any) -> bool:
+        return a > b
+
     def __hash__(self) -> int:
         return self.name.__hash__()
 
