@@ -24,4 +24,4 @@ class NovaPoshtaCodeSeeker(CodeSeeker):
         })
 
 
-NOVAPOSHTA_SEEKER = NovaPoshtaCodeSeeker('NOVAPOSHTA')
+NOVAPOSHTA_SEEKER = NovaPoshtaCodeSeeker(name='NOVAPOSHTA')
